%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Title: getp0h
%  Author: CGN
%    Date: 10/17/16
% Purpose: calculates house price at time 0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [p0h] = getp0h(N0,x,z,params)

    % unpack relevant parameters
    mub=params.mub;
    theta=params.theta;
    k=params.k;
    eps=params.eps;
    f=params.f;
    D=params.D;
    p1h=params.p1h;

    % calculate mu using z
    mu = mub + z*theta;
    mumax = max(mu);
    
    % get N0*(x,z)
    N0star = getN0star(x,z,params);
    
    % seed
    p0h = zeros(size(N0));
    
    % low regime
    if sum(N0<=N0star)>0
        d = exp(-mumax*x);
        ind = (N0<=N0star);
        p0h(ind) = k + k*(1+(N0(ind)/d-1).*(N0(ind)>d)).^(1/eps);
    end
    
    % high regime
    if sum(N0>N0star)>0
        ind = (N0>N0star);
        list = find(ind);
        if x==0 || z==0
            p0h(ind) = k*(1+exp(mub*x/eps))*N0(ind).^(1/eps);
        else
            pmin = k + k*exp(mumax*x/eps)*N0(ind).^(1/eps);
            pmax = k*(1+exp(mumax*x/eps))*N0(ind).^(1/eps);
            for j=1:numel(list)
                p0h(list(j))=fzero(@(p0h) 1 - ...
                    N0(list(j))*f'*D(p0h-p1h(exp(mu*x)*N0(list(j)))), ...
                        [pmin(j),pmax(j)]);
            end
        end
    end
end