/************
attempt to replicate figures
************/

/*delimit with semicolon*/
#d;

/*egen for weighted means*/
ssc install _gwtmean, replace;

/************
figure 3
************/

/*use merged fhfa file*/
use ../data/fhfa_2013_q2_merge_correct, clear;

/*convert zeros in land booms to missings*/
replace boom0006_land = . if boom0006_land==0;

/*generate total percentage price increase, 2000-2006*/
gen cum_price_increase= exp(6*boom0006_fixed)-1;

/*same for land price increase*/
gen cum_land_increase = exp(6*boom0006_land)-1;

/*same for construction cost increase*/
gen cum_ccost_increase = exp(6*ccost_av_0006)-1;

/*scatter construction cost and land price growth against home price growth*/
twoway 
	(scatter cum_ccost_increase cum_price_increase if year==2000, 
		msymbol(O)) ||
	(scatter cum_land_increase cum_price_increase if year==2000, 
		msymbol(Dh) mcolor(green)),
		xtitle("House Price Increase")
		ytitle("Input Price Increase")
		legend(order(1 "Construction Costs" 2 "Land Prices") 
			cols(1) rows(2) pos(11) ring(0))
		xlabel(0 "0%" 0.5 "50%" 1 "100%" 1.5 "150%")
		ylabel(0 "0%" 0.5 "50%" 1 "100%" 1.5 "150%" 2 "200%" 2.5 "250%", 
			angle(0) nogrid)
		graphregion(color(white))
		plotregion(lcolor(black))
		xsize(4)
		ysize(6);

/*save color version*/
graph export ../output/figure_3.eps, replace;
graph export ../output/figure_3.pdf, replace;

/*generate black and white version*/
twoway 
	(scatter cum_ccost_increase cum_price_increase if year==2000, 
		msymbol(O)) ||
	(scatter cum_land_increase cum_price_increase if year==2000, 
		msymbol(Dh)),
		xtitle("House Price Increase")
		ytitle("Input Price Increase")
		legend(order(1 "Construction Costs" 2 "Land Prices") 
			cols(1) rows(2) pos(11) ring(0))
		xlabel(0 "0%" 0.5 "50%" 1 "100%" 1.5 "150%")
		ylabel(0 "0%" 0.5 "50%" 1 "100%" 1.5 "150%" 2 "200%" 2.5 "250%", 
			angle(0) nogrid)
		graphregion(color(white))
		plotregion(lcolor(black))
		xsize(4)
		ysize(6)
		scheme(s2mono);

/*save black and white*/
graph export ../output/figure_3_bw.eps, replace;

/************
figure 4
************/

/*use handcoded builder data*/
use ../data/builders_handcoded, clear;

/*plot figure 4a*/
twoway 
	(scatter total_lots_controlled year if ticD==2,
		c(l) msymbol(O)) ||
	(scatter total_homes_closed year if ticD==2,
		c(l) msymbol(Dh) lpattern(dash)),
		legend(order(1 "Lots Controlled" 2 "Home Sales")
			cols(1) rows(2) pos(11) ring(0))
		ylabel(500000 "500,000" 1000000 "1,000,000" 1500000 "1,500,000"
			2000000 "2,000,000", angle(0) nogrid)
		graphregion(color(white))
		plotregion(lcolor(black))
		xtitle("Year");
tempfile figure_4a;
graph save `figure_4a', replace;

/*save as eps color, eps black-white, pdf*/
graph export ../output/figure_4a.eps, replace;
graph export ../output/figure_4a.pdf, replace;
graph use `figure_4a', scheme(s2mono);
graph export ../output/figure_4a_bw.eps, replace;

/*total land and deposit impairments between 2006 and 2010*/
sum impairments_land if year>=2006 & year<=2010;
local 0610_land_imp = `r(sum)';
sum impairments_deposits if year>=2006 & year<=2010;
local 0610_deposit_imp = `r(sum)';
local 0610_landdeposit_imp = `0610_land_imp' + `0610_deposit_imp';

/*total impairments*/
sum impairments_total if year>=2006 & year<=2010;
local 0610_total_imp = `r(sum)';

/*market equity at end of 2010*/
sum total_market_equity if ticD==2 & year==2010;
local market_equity_10 = `r(mean)';
gen market_equity_10 = `market_equity_10' if year==2005;
local arrow_bottom = 0.95*`market_equity_10';

/*market equity at end of 2005*/
sum total_market_equity if ticD==2 & year==2005;
local market_equity_05 = `r(mean)';

/*2005 equity adjusted for future equity values and impairments*/
gen equity_adjust_05 = market_equity_10 + `0610_landdeposit_imp' if year==2005;

/*display numbers in text*/
n disp "Land and deposit impairments: " `0610_landdeposit_imp' " million";
n disp "Impairment share of equity decline: " 
	`0610_landdeposit_imp'/(`market_equity_05'-`market_equity_10');
n disp "Total impairments: " `0610_total_imp' " million";

/*plot figure 4b*/
twoway 
	(scatter total_market_equity year, c(l)) ||
	(pcbarrow market_equity_10 year equity_adjust_05 year,
		lcolor(black) mcolor(black) msize(large)) if ticD==2,
		xtitle("Year")
		ytitle("")
		ylabel(0 "$0B" 20000 "$20B" 40000 "$40B" 60000 "$60B",
			angle(0) nogrid)
		graphregion(color(white))
		plotregion(lcolor(black))
		legend(off)
		text(`arrow_bottom' 2005
			"Land Writedowns"
			"2006-2010", placement(se) justification(left));
tempfile figure_4b;
graph save `figure_4b', replace;

/*save as eps color, eps black-white, pdf*/
graph export ../output/figure_4b.eps, replace;
graph export ../output/figure_4b.pdf, replace;
graph use `figure_4b', scheme(s2mono);
graph export ../output/figure_4b_bw.eps, replace;

/************
figure 5
************/

/*use merged fhfa file*/
use ../data/fhfa_2013_q2_merge_correct, clear;

/*generate total percentage price increase, 2000-2006*/
gen cum_price_increase= exp(6*boom0006_fixed)-1;

/*label anomaly cities*/
drop anomaly;
gen anomaly = inlist(msa,
	12540,
	19660,
	22744,
	23420,
	27260,
	29820,
	33124,
	33700,
	36740,
	38060,
	39900,
	40140,
	40900,
	44700,
	45300,
	46060,
	48424);
	
/*label inelastic cities*/
drop inelastic;
gen inelastic = inlist(msa,
	11244,
	14454,
	14860,
	15764,
	15804,
	31084,
	34900,
	35004,
	35084,
	35614,
	36084,
	37100,
	37964,
	38900,
	39300,
	41500,
	41740,
	41884,
	41940,
	42020,
	42100,
	42200,
	42220,
	42644,
	45104,
	46520,
	46700);
	
/*plot figure 5a*/
twoway
	(scatter cum_price_increase growth0006 
		if anomaly & year==2000, msymbol(O)) ||
	(scatter cum_price_increase growth0006 
		if inelastic & year==2000, msymbol(Dh)) ||
	(scatter cum_price_increase growth0006 
		if ~anomaly & ~inelastic & year==2000,
			msymbol(plus) mcolor(gs10)),
		xtitle("Annual Housing Stock Growth")
		ytitle("Cumulative Price Increase")
		legend(order(1 "Anomalous Cities" 2 "Inelastic Cities") 
			cols(1) rows(2) pos(2) ring(0))
		xlabel(0 "0%" 0.01 "1%" 0.02 "2%" 0.03 "3%" 0.04 "4%" 0.05 "5%")
		ylabel(0 "0%" 0.5 "50%" 1 "100%" 1.5 "150%", angle(0) nogrid)
		graphregion(color(white))
		plotregion(lcolor(black));
tempfile figure_5a;
graph save `figure_5a', replace;

/*save as eps color, eps black-white, pdf*/
graph export ../output/figure_5a.eps, replace;
graph export ../output/figure_5a.pdf, replace;
graph use `figure_5a', scheme(s2mono);
graph export ../output/figure_5a_bw.eps, replace;

/*compute annual construction intensity by metro*/
bys msa (year): gen construction = (imputedhousing[_n+1]/imputedhousing)-1;

/*compute housing capital gains since 1980*/
gen sample_year=(year>=1980&year<=2011);
bys msa sample_year (year): gen cum_cap_gain = 
	(FHFA_index_float/FHFA_index_float[1])/(cpi/cpi[1])-1
		if sample_year==1;

/*tempfile for construction and cap gain averages*/
tempfile averages;

/*compute annual construction and cap gain averages by group*/
preserve;
	collapse 
		construction_total=construction 
		cum_cap_gain_total=cum_cap_gain
			[weight=stock_2000], by(year);
	save `averages', replace;
restore;
preserve;
	collapse 
		construction_inelastic=construction 
		cum_cap_gain_inelastic=cum_cap_gain
			[weight=stock_2000] if inelastic, by(year);
	merge 1:1 year using `averages', nogen;
	save `averages', replace;
restore;
collapse 
	construction_anomaly=construction
	cum_cap_gain_anomaly=cum_cap_gain
		[weight=stock_2000] if anomaly, by(year);
merge 1:1 year using `averages', nogen;
	
/*plot figure 5b*/
twoway
	(line construction_anomaly year) ||
	(line construction_inelastic year, lpattern(dash)) ||
	(line construction_total year, lcolor(gs10) lpattern(dash_dot))
	if construction_total~=.,
		ylabel(0 "0%" 0.01 "1%" 0.02 "2%" 0.03 "3%" 0.04 "4%" 0.05 "5%",
			angle(0) nogrid)
		xlabel(1980(5)2005)
		xscale(range(1979 2008))
		ytitle("")
		xtitle("")
		legend(
			order(1 "Anomalous Cities" 3 "U.S. Average" 2 "Inelastic Cities")
			cols(1) rows(3) pos(2) ring(0))
		graphregion(color(white))
		plotregion(lcolor(black));
tempfile figure_5b;
graph save `figure_5b', replace;

/*save as eps color, eps black-white, pdf*/
graph export ../output/figure_5b.eps, replace;
graph export ../output/figure_5b.pdf, replace;
graph use `figure_5b', scheme(s2mono);
graph export ../output/figure_5b_bw.eps, replace;

/*capital gains in 2000*/
sum cum_cap_gain_total if year==2000;
local 2000_total = `r(mean)';
sum cum_cap_gain_anomaly if year==2000;
local 2000_anomaly = `r(mean)';
sum cum_cap_gain_inelastic if year==2000;
local 2000_inelastic = `r(mean)';

/*plot figure 5c in color*/
twoway
	(line cum_cap_gain_anomaly year) ||
	(line cum_cap_gain_inelastic year, lpattern(dash)) ||
	(line cum_cap_gain_total year, lcolor(gs10) lpattern(dash_dot)) ||
	(scatteri `2000_anomaly' 2000, mcolor(edkblue) msymbol(O)) ||
	(scatteri `2000_inelastic' 2000, mcolor(maroon) msymbol(O)) ||
	(scatteri `2000_total' 2000, mcolor(gs10) msymbol(O))
	if cum_cap_gain_total~=.,
		ylabel(0 "0%" 0.5 "50%" 1 "100%" 1.5 "150%",
			angle(0) nogrid)
		xlabel(1980(5)2010)
		xscale(range(1980 2011))
		ytitle("")
		xtitle("")
		legend(
			order(1 "Anomalous Cities" 3 "U.S. Average" 2 "Inelastic Cities")
			cols(1) rows(3) pos(11) ring(0))
		graphregion(color(white))
		plotregion(lcolor(black))
		xline(2000, lpattern(dot) lcolor(gs10));

/*save figure 5c in color*/
graph export ../output/figure_5c.eps, replace;
graph export ../output/figure_5c.pdf, replace;

/*plot figure 5c in black and white*/
twoway
	(line cum_cap_gain_anomaly year) ||
	(line cum_cap_gain_inelastic year, lpattern(dash)) ||
	(line cum_cap_gain_total year, lcolor(gs10) lpattern(dash_dot)) ||
	(scatteri `2000_anomaly' 2000, msymbol(O)) ||
	(scatteri `2000_inelastic' 2000, msymbol(O)) ||
	(scatteri `2000_total' 2000, msymbol(O))
	if cum_cap_gain_total~=.,
		ylabel(0 "0%" 0.5 "50%" 1 "100%" 1.5 "150%",
			angle(0) nogrid)
		xlabel(1980(5)2010)
		xscale(range(1980 2011))
		ytitle("")
		xtitle("")
		legend(
			order(1 "Anomalous Cities" 3 "U.S. Average" 2 "Inelastic Cities")
			cols(1) rows(3) pos(11) ring(0))
		graphregion(color(white))
		plotregion(lcolor(black))
		xline(2000, lpattern(dot) lcolor(gs10))
		scheme(s2mono);

/*save figure 5c in black and white*/
graph export ../output/figure_5c_bw.eps, replace;
window manage close graph;		
